import { GetListParams, GetOneParams, GetManyParams, GetManyReferenceParams, CreateParams, UpdateParams, UpdateManyParams, DeleteParams, DeleteManyParams, DataProvider } from 'react-admin';
import { AxiosResponse, AxiosInterceptorOptions, AxiosRequestConfig } from 'axios';
import { PrismaClient } from '@prisma/client';

declare type AuditOptions = {
    model?: {
        create: Function;
    };
    authProvider?: any;
    columns?: {
        id?: string;
        date?: string;
        resource?: string;
        action?: string;
        payload?: string;
        author?: string;
    };
    enabledForAction?: {
        create?: boolean;
        update?: boolean;
        delete?: boolean;
    };
    enabledResources?: string[];
};

declare type Request = GetListRequest | GetOneRequest | GetManyRequest | GetManyReferenceRequest | CreateRequest | UpdateRequest | UpdateManyRequest | DeleteRequest | DeleteManyRequest;
declare type GetListRequest = {
    body: {
        method: "getList";
        filter: object;
        params: GetListParams;
        resource: string;
        model?: string;
    };
};
declare type GetOneRequest = {
    body: {
        method: "getOne";
        params: GetOneParams;
        resource: string;
        model?: string;
    };
};
declare type GetManyRequest = {
    body: {
        method: "getMany";
        params: GetManyParams;
        resource: string;
        model?: string;
    };
};
declare type GetManyReferenceRequest = {
    body: {
        method: "getManyReference";
        params: GetManyReferenceParams;
        resource: string;
        model?: string;
    };
};
declare type CreateRequest = {
    body: {
        method: "create";
        params: CreateParams;
        resource: string;
        model?: string;
    };
};
declare type UpdateRequest = {
    body: {
        method: "update";
        params: UpdateParams;
        resource: string;
        model?: string;
    };
};
declare type UpdateManyRequest = {
    body: {
        method: "updateMany";
        params: UpdateManyParams;
        resource: string;
        model?: string;
    };
};
declare type DeleteRequest = {
    body: {
        method: "delete";
        params: DeleteParams;
        resource: string;
        model?: string;
    };
};
declare type DeleteManyRequest = {
    body: {
        method: "deleteMany";
        params: DeleteManyParams;
        resource: string;
        model?: string;
    };
};
declare type Send<T> = (body: T) => void;
declare type Response<T extends {
    data: any;
} = any> = {
    json: Send<T>;
};

declare const createHandler: <T extends {
    create: Function;
}>(req: CreateRequest, res: Response, table: T, options?: {
    connect?: {
        [key: string]: string;
    };
}, audit?: AuditOptions) => Promise<void>;

declare const dataProvider: (endpoint: string, options?: {
    resourceToModelMap?: Record<string, string>;
    axiosInterceptors?: {
        response?: {
            onFulfilled?: (value: AxiosResponse<any, any>) => any;
            onRejected?: (error: any) => any;
            options?: AxiosInterceptorOptions;
        }[];
        request?: {
            onFulfilled?: (value: AxiosRequestConfig<any>) => AxiosRequestConfig<any> | Promise<AxiosRequestConfig<any>>;
            onRejected?: (error: any) => any;
            options?: AxiosInterceptorOptions;
        }[];
    };
}) => DataProvider;

declare type DeleteOptions = {
    softDeleteField?: string;
    debug?: boolean;
};
declare const deleteHandler: <T extends {
    update: Function;
    delete: Function;
}>(req: DeleteRequest, res: Response, table: T, options?: DeleteOptions, audit?: AuditOptions) => Promise<void>;

declare type GetListOptions = {
    noNullsOnSort?: string[];
    debug?: boolean;
    transform?: (data: any) => any;
};
declare const getListHandler: <W extends {
    include?: object | null;
    orderBy?: object | null;
    select?: object | null;
    skip?: number | null;
    take?: number | null;
    where?: object | null;
}>(req: GetListRequest, res: Response, table: {
    findMany: Function;
    count: Function;
}, options?: {
    select?: W["select"];
    include?: W["include"];
    where?: W["where"];
    noNullsOnSort?: string[];
    debug?: boolean;
    transform?: (data: any) => any;
}) => Promise<void>;

declare type UpdateOptions = {
    debug?: boolean;
    skipFields?: {
        [key: string]: boolean;
    };
    set?: {
        [key: string]: string;
    };
    allowNestedUpdate?: {
        [key: string]: boolean;
    };
    allowNestedUpsert?: {
        [key: string]: boolean;
    };
};
declare const updateHandler: (req: UpdateRequest, res: Response, model: {
    update: Function;
}, options?: UpdateOptions, audit?: AuditOptions) => Promise<void>;

declare const defaultHandler: (req: Request, res: Response, prisma: PrismaClient, options?: {
    delete?: DeleteOptions;
    update?: UpdateOptions;
    getList?: GetListOptions;
    audit?: AuditOptions;
}) => Promise<void>;

declare type DeleteManyOptions = {
    softDeleteField?: string;
};
declare const deleteManyHandler: <T extends {
    updateMany: Function;
    deleteMany: Function;
}>(req: DeleteManyRequest, res: Response, table: T, options?: DeleteManyOptions, audit?: AuditOptions) => Promise<void>;

declare const extractOrderBy: (req: GetListRequest | GetManyReferenceRequest) => {};

declare const extractSkipTake: (req: GetListRequest | GetManyReferenceRequest) => {
    skip: any;
    take: any;
};

declare const extractWhere: (req: GetListRequest | GetManyReferenceRequest) => {};

declare const getManyHandler: (req: GetManyRequest, res: Response, table: {
    findMany: Function;
}) => Promise<void>;

declare const getManyReferenceHandler: (req: GetManyReferenceRequest, res: Response, table: {
    findMany: Function;
}) => Promise<void>;

declare const getOneHandler: <W extends {
    include?: object | null;
    select?: object | null;
}>(req: GetOneRequest, res: Response, model: {
    findUnique: Function;
}, options?: {
    select?: W["select"];
    include?: W["include"];
    debug?: boolean;
    transform?: (row: any) => any;
}) => Promise<void>;

export { CreateRequest, DeleteManyOptions, DeleteManyRequest, DeleteOptions, DeleteRequest, GetListOptions, GetListRequest, GetManyReferenceRequest, GetManyRequest, GetOneRequest, Request, Response, UpdateManyRequest, UpdateOptions, UpdateRequest, createHandler, dataProvider, defaultHandler, deleteHandler, deleteManyHandler, extractOrderBy, extractSkipTake, extractWhere, getListHandler, getManyHandler, getManyReferenceHandler, getOneHandler, updateHandler };
